Animanager
==========

Website: https://darkfeline.github.io/animanager/

Animanager is a personal anime database management tool.

Please consult the documentation for more information.  It can be found in the
`doc` directory, or online at
[Read the Docs](http://animanager.readthedocs.org/).
